pub struct OpaClient { /* private fields */ }Expand description
Client for interacting with an Open Policy Agent (OPA) server or WASM module.
Implementations
Sourceimpl OpaClient
impl OpaClient
Sourcepub fn new(url: Option<String>, tls_config: Option<Arc<ClientConfig>>) -> Self
pub fn new(url: Option<String>, tls_config: Option<Arc<ClientConfig>>) -> Self
Creates a new OpaClient with the given URL and TLS configuration.
Sourcepub fn with_wasm_executor(self, executor: Arc<dyn OpaWasmExecutor>) -> Self
pub fn with_wasm_executor(self, executor: Arc<dyn OpaWasmExecutor>) -> Self
Configures the client to use a WASM executor.
Sourcepub fn with_entrypoint(self, entrypoint: String) -> Self
pub fn with_entrypoint(self, entrypoint: String) -> Self
Sets the entrypoint for the OPA policy.
Sourcepub fn is_configured(&self) -> bool
pub fn is_configured(&self) -> bool
Returns true if the client is configured with either a URL or a WASM executor.
Sourcepub async fn check_context<T: Serialize>(&self, context: T) -> Result<bool>
pub async fn check_context<T: Serialize>(&self, context: T) -> Result<bool>
Flexible check that sends any serializable context to OPA