pub struct StepCompletedEvent {
pub run_id: RunId,
pub step_id: StepInstanceId,
pub event_type: EventType,
pub runner_id: Option<String>,
pub storage_hashes: Option<HashMap<String, Value>>,
pub artifacts: Option<HashMap<String, Value>>,
pub test_reports: Option<HashMap<String, Value>>,
pub outputs: Option<HashMap<String, Value>>,
pub exit_code: Option<i32>,
pub timestamp: DateTime<Utc>,
}Fields
run_id: RunIdstep_id: StepInstanceIdevent_type: EventTyperunner_id: Option<String>storage_hashes: Option<HashMap<String, Value>>artifacts: Option<HashMap<String, Value>>test_reports: Option<HashMap<String, Value>>outputs: Option<HashMap<String, Value>>exit_code: Option<i32>timestamp: DateTime<Utc>Trait Implementations
Sourceimpl Clone for StepCompletedEvent
impl Clone for StepCompletedEvent
Sourcefn clone(&self) -> StepCompletedEvent
fn clone(&self) -> StepCompletedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StepCompletedEvent
impl Debug for StepCompletedEvent
Sourceimpl<'de> Deserialize<'de> for StepCompletedEvent
impl<'de> Deserialize<'de> for StepCompletedEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StepCompletedEvent
impl JsonSchema for StepCompletedEvent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StepCompletedEvent
impl RefUnwindSafe for StepCompletedEvent
impl Send for StepCompletedEvent
impl Sync for StepCompletedEvent
impl Unpin for StepCompletedEvent
impl UnsafeUnpin for StepCompletedEvent
impl UnwindSafe for StepCompletedEvent