pub struct StepRunningEvent {
pub run_id: RunId,
pub step_id: StepInstanceId,
pub event_type: EventType,
pub runner_id: Option<String>,
pub timestamp: DateTime<Utc>,
}Fields
run_id: RunIdstep_id: StepInstanceIdevent_type: EventTyperunner_id: Option<String>timestamp: DateTime<Utc>Trait Implementations
Sourceimpl Clone for StepRunningEvent
impl Clone for StepRunningEvent
Sourcefn clone(&self) -> StepRunningEvent
fn clone(&self) -> StepRunningEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StepRunningEvent
impl Debug for StepRunningEvent
Sourceimpl<'de> Deserialize<'de> for StepRunningEvent
impl<'de> Deserialize<'de> for StepRunningEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StepRunningEvent
impl JsonSchema for StepRunningEvent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StepRunningEvent
impl RefUnwindSafe for StepRunningEvent
impl Send for StepRunningEvent
impl Sync for StepRunningEvent
impl Unpin for StepRunningEvent
impl UnsafeUnpin for StepRunningEvent
impl UnwindSafe for StepRunningEvent