pub struct StepScheduledEvent {
pub run_id: RunId,
pub step_id: StepInstanceId,
pub step_name: Option<String>,
pub step_type: Option<String>,
pub event_type: EventType,
pub step_dsl: Value,
pub spec: Option<Value>,
pub params: Option<Value>,
pub storage: Option<HashMap<String, Value>>,
pub test_report_urls: Option<HashMap<String, Value>>,
pub timestamp: DateTime<Utc>,
}Fields
run_id: RunIdstep_id: StepInstanceIdstep_name: Option<String>step_type: Option<String>event_type: EventTypestep_dsl: Valuespec: Option<Value>params: Option<Value>storage: Option<HashMap<String, Value>>test_report_urls: Option<HashMap<String, Value>>timestamp: DateTime<Utc>Trait Implementations
Sourceimpl Clone for StepScheduledEvent
impl Clone for StepScheduledEvent
Sourcefn clone(&self) -> StepScheduledEvent
fn clone(&self) -> StepScheduledEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StepScheduledEvent
impl Debug for StepScheduledEvent
Sourceimpl<'de> Deserialize<'de> for StepScheduledEvent
impl<'de> Deserialize<'de> for StepScheduledEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StepScheduledEvent
impl JsonSchema for StepScheduledEvent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StepScheduledEvent
impl RefUnwindSafe for StepScheduledEvent
impl Send for StepScheduledEvent
impl Sync for StepScheduledEvent
impl Unpin for StepScheduledEvent
impl UnsafeUnpin for StepScheduledEvent
impl UnwindSafe for StepScheduledEvent