pub struct WorkflowCompletedEvent {
pub run_id: RunId,
pub event_type: EventType,
pub timestamp: DateTime<Utc>,
}Fields
run_id: RunIdevent_type: EventTypetimestamp: DateTime<Utc>Trait Implementations
Sourceimpl Clone for WorkflowCompletedEvent
impl Clone for WorkflowCompletedEvent
Sourcefn clone(&self) -> WorkflowCompletedEvent
fn clone(&self) -> WorkflowCompletedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkflowCompletedEvent
impl Debug for WorkflowCompletedEvent
Sourceimpl<'de> Deserialize<'de> for WorkflowCompletedEvent
impl<'de> Deserialize<'de> for WorkflowCompletedEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkflowCompletedEvent
impl JsonSchema for WorkflowCompletedEvent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkflowCompletedEvent
impl RefUnwindSafe for WorkflowCompletedEvent
impl Send for WorkflowCompletedEvent
impl Sync for WorkflowCompletedEvent
impl Unpin for WorkflowCompletedEvent
impl UnsafeUnpin for WorkflowCompletedEvent
impl UnwindSafe for WorkflowCompletedEvent