pub struct WorkflowQueuedEvent {
pub run_id: RunId,
pub event_type: EventType,
pub timestamp: DateTime<Utc>,
pub dsl: Option<String>,
pub inputs: Option<HashMap<String, Value>>,
pub initiating_user: Option<String>,
}Fields
run_id: RunIdevent_type: EventTypetimestamp: DateTime<Utc>dsl: Option<String>inputs: Option<HashMap<String, Value>>initiating_user: Option<String>Trait Implementations
Sourceimpl Clone for WorkflowQueuedEvent
impl Clone for WorkflowQueuedEvent
Sourcefn clone(&self) -> WorkflowQueuedEvent
fn clone(&self) -> WorkflowQueuedEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkflowQueuedEvent
impl Debug for WorkflowQueuedEvent
Sourceimpl<'de> Deserialize<'de> for WorkflowQueuedEvent
impl<'de> Deserialize<'de> for WorkflowQueuedEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WorkflowQueuedEvent
impl JsonSchema for WorkflowQueuedEvent
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorkflowQueuedEvent
impl RefUnwindSafe for WorkflowQueuedEvent
impl Send for WorkflowQueuedEvent
impl Sync for WorkflowQueuedEvent
impl Unpin for WorkflowQueuedEvent
impl UnsafeUnpin for WorkflowQueuedEvent
impl UnwindSafe for WorkflowQueuedEvent