pub enum LogBackend {
Loki {
url: String,
},
Elasticsearch {
url: String,
index: String,
},
}Expand description
Represents the supported logging backends for step execution logs.
Variants
Implementations
Sourceimpl LogBackend
impl LogBackend
Sourcepub async fn fetch_step_logs(
&self,
step_name: &str,
step_id: StepInstanceId,
started_at: Option<DateTime<Utc>>,
finished_at: Option<DateTime<Utc>>,
limit: Option<usize>,
) -> Result<Vec<String>>
pub async fn fetch_step_logs( &self, step_name: &str, step_id: StepInstanceId, started_at: Option<DateTime<Utc>>, finished_at: Option<DateTime<Utc>>, limit: Option<usize>, ) -> Result<Vec<String>>
Fetches historical logs for a specific step instance.
Sourcepub async fn stream_step_logs(
&self,
step_name: &str,
step_id: StepInstanceId,
) -> Result<Receiver<Result<String>>>
pub async fn stream_step_logs( &self, step_name: &str, step_id: StepInstanceId, ) -> Result<Receiver<Result<String>>>
Opens a real-time stream of log lines for a currently executing step instance.