Module step

Module step 

Workflow step execution models and state. Workflow step execution models and state.

Structs

StepInstance
Represents the execution instance of a specific step in a workflow.
StepOutput
A key-value output generated by a step execution.
StepStatusHistory
A historical record of a status transition for a step instance.

Enums

StepStatus
The execution status of a single workflow step.