Crate stormchaser_model

Crate stormchaser_model 

Core data models and domain types for the Stormchaser workflow engine.

This crate provides the foundational types representing workflows, steps, executions, and other entities that make up the domain model.

Re-exports

pub use auth::ApiOpaContext;
pub use auth::Claims;
pub use auth::EngineOpaContext;
pub use auth::OpaClient;
pub use dsl::ApprovalSpec;
pub use dsl::WaitEventSpec;
pub use event::ApprovalRegistry;
pub use event::EventCorrelation;
pub use event_rules::EventRule;
pub use event_rules::WebhookConfig;
pub use logging::LogBackend;
pub use outbox::OutboxMessage;
pub use runner::Runner;
pub use runner::RunnerStatus;
pub use runner::StepDefinition;
pub use step::StepInstance;
pub use step::StepOutput;
pub use step::StepStatus;
pub use storage::BackendType;
pub use storage::StorageBackend;
pub use test_report::TestCase;
pub use test_report::TestCaseStatus;
pub use test_report::TestReport;
pub use test_report::TestSummary;
pub use workflow::AuditLog;
pub use workflow::RunContext;
pub use workflow::RunQuotas;
pub use workflow::RunStatus;
pub use workflow::WorkflowRun;
pub use id::*;

Modules

auth
Authentication and authorization models. Authentication and authorization models and OPA client.
cron
Cron scheduling definitions. Cron scheduling models for recurring workflow execution.
dsl
Domain-Specific Language (DSL) abstract syntax tree and types. Domain-Specific Language (DSL) abstract syntax tree and types.
event
System event and correlation models. System event and correlation models for async execution.
event_rules
Rule-based trigger definitions for events. Rule-based event processing and webhook configuration models.
events
Event schemas for CloudEvents.
hcl_eval
HCL expression evaluation models. Hcl expression evaluation models and conversion utilities.
id
logging
Logging configuration and log streaming types.
nats
NATS helpers.
outbox
Outbox pattern models for reliable message publishing. Outbox pattern models for reliable event publishing.
runner
Execution runner definitions and status models. Models for workflow runner instances and step definitions.
schema_cache
Schema cache for OCI schemas.
schema_gen
Schema generation functions.
step
Workflow step execution models and state. Workflow step execution models and state.
storage
Storage backend and artifact registry models. Storage backend and artifact registry models.
test_report
Test reporting and summary models. Test reporting and summary models for workflow execution.
workflow
Core workflow run and state management types. Core workflow run and state management types.

Traits

WorkflowEngine
Engine trait for scheduling and managing workflow runs.