Workflow step execution models and state. Workflow step execution models and state.
Structs
- Step
Instance - Represents the execution instance of a specific step in a workflow.
- Step
Output - A key-value output generated by a step execution.
- Step
Status History - A historical record of a status transition for a step instance.
Enums
- Step
Status - The execution status of a single workflow step.